@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.30';
+  $CPAN::Perl::Releases::VERSION = '0.32';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -220,6 +220,10 @@ our $data =
     "tar.bz2" => "R/RJ/RJBS/perl-5.15.2.tar.bz2",
     "tar.gz" => "R/RJ/RJBS/perl-5.15.2.tar.gz",
   },
+  "5.15.3" => {
+    "tar.bz2" => "S/ST/STEVAN/perl-5.15.3.tar.bz2",
+    "tar.gz" => "S/ST/STEVAN/perl-5.15.3.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -328,7 +332,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.30
+version 0.32
 
 =head1 SYNOPSIS
 
